API Docs
=======================

.. note:: The :class:`~tabledataextractor.table.table.Table` object is everything you need to use `TableDataExtractor`. The other sections, :ref:`input`, :ref:`output`, :ref:`history`, :ref:`footnotes`, :ref:`algorithms`, :ref:`cell_parser`, and :ref:`exceptions` are for reference only.


.. toctree::
   :maxdepth: 1
   :caption: Contents:

   table_object
   input
   output
   history
   footnotes
   algorithms
   cell_parser
   exceptions